[Buildbot-commits] buildbot/buildbot/clients debug.py,1.10,1.11

Brian Warner warner at users.sourceforge.net
Thu May 22 22:13:24 UTC 2008


Update of /cvsroot/buildbot/buildbot/buildbot/clients
In directory sc8-pr-cvs3.sourceforge.net:/tmp/cvs-serv17705/buildbot/clients

Modified Files:
	debug.py 
Log Message:
[project @ #124:remove-custom-props.patch]
Remove custom properties, which are now largely redundant, and on which the
properties interface was modeled.

Original author: dustin at v.igoro.us
Date: 2008-04-13 19:55:26+00:00

Index: debug.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/clients/debug.py,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -d -r1.10 -r1.11
--- debug.py	22 May 2008 22:12:42 -0000	1.10
+++ debug.py	22 May 2008 22:13:21 -0000	1.11
@@ -104,9 +104,9 @@
             if revision == '':
                 revision = None
         reason = "debugclient 'Request Build' button pushed"
-        custom_props = {}
+        properties = {}
         d = self.remote.callRemote("requestBuild",
                                    name, reason, branch, revision, custom_props)
         d.addErrback(self.err)
 
     def do_ping(self, widget):
@@ -104,9 +104,9 @@
         d = self.remote.callRemote("requestBuild",
-                                   name, reason, branch, revision, custom_props)
+                                   name, reason, branch, revision, properties)
         d.addErrback(self.err)
 





More information about the Commits mailing list